@@ -190,7 +190,8 @@ pub const HTML_CONFIG_DARK_DEFAULT: &str = "<style>.poloto {\
     .poloto6fill{fill:lime;}\
     .poloto7fill{fill:chocolate;}</style>";
 
-const DIMENSIONS: [usize; 2] = [800, 500];
+/// The demsions of the svg graph `[800,500]`.
+pub const DIMENSIONS: [usize; 2] = [800, 500];
 
 /// Iterators that are passed to the [`Plotter`] plot functions must produce
 /// items that implement this trait.
@@ -201,14 +202,14 @@ pub trait Plottable {
 
 /// Convert other primitive types to f64 using this trait.
 /// Precision loss is considered acceptable, since this is just for visual human eyes.
-pub trait IntoF64: Copy {
-    fn into_f64(self) -> f64;
+pub trait AsF64: Copy {
+    fn as_f64(self) -> f64;
 }
 
 macro_rules! impl_into_plotnum {
     ($U: ty ) => {
-        impl IntoF64 for $U {
-            fn into_f64(self) -> f64 {
+        impl AsF64 for $U {
+            fn as_f64(self) -> f64 {
                 self as f64
             }
         }
@@ -230,31 +231,31 @@ impl_into_plotnum!(u128);
 impl_into_plotnum!(isize);
 impl_into_plotnum!(usize);
 
-impl<T: IntoF64> Plottable for [T; 2] {
+impl<T: AsF64> Plottable for [T; 2] {
     fn make_plot(self) -> [f64; 2] {
         let [x, y] = self;
-        [x.into_f64(), y.into_f64()]
+        [x.as_f64(), y.as_f64()]
     }
 }
 
-impl<T: IntoF64> Plottable for &[T; 2] {
+impl<T: AsF64> Plottable for &[T; 2] {
     fn make_plot(self) -> [f64; 2] {
         let [x, y] = self;
-        [x.into_f64(), y.into_f64()]
+        [x.as_f64(), y.as_f64()]
     }
 }
 
-impl<T: IntoF64> Plottable for (T, T) {
+impl<T: AsF64> Plottable for (T, T) {
     fn make_plot(self) -> [f64; 2] {
         let (x, y) = self;
-        [x.into_f64(), y.into_f64()]
+        [x.as_f64(), y.as_f64()]
     }
 }
 
-impl<T: IntoF64> Plottable for &(T, T) {
+impl<T: AsF64> Plottable for &(T, T) {
     fn make_plot(self) -> [f64; 2] {
         let (x, y) = self;
-        [x.into_f64(), y.into_f64()]
+        [x.as_f64(), y.as_f64()]
     }
 }
 
@@ -264,7 +265,7 @@ impl<T: IntoF64> Plottable for &(T, T) {
 /// Shorthand for
 /// ```
 /// use tagger::prelude::*;
-/// let p =poloto::Plotter::new(poloto::default_svg().add(single!(poloto::HTML_CONFIG_LIGHT_DEFAULT)),"title","xname","yname");
+/// let p =poloto::Plotter::new(poloto::default_svg().appendm(single!(poloto::HTML_CONFIG_LIGHT_DEFAULT)),"title","xname","yname");
 /// ```
 ///
 pub fn plot<'a>(
@@ -273,7 +274,7 @@ pub fn plot<'a>(
     yname: impl Display + 'a,
 ) -> Plotter<'a> {
     Plotter::new(
-        default_svg().add(single!(HTML_CONFIG_LIGHT_DEFAULT)),
+        default_svg().appendm(single!(HTML_CONFIG_LIGHT_DEFAULT)),
         title,
         xname,
         yname,
@@ -302,8 +303,8 @@ impl<'a> Plotter<'a> {
     /// Create a plotter with the specified element.
     ///
     /// ```
-    /// let svg=poloto::default_svg();
-    /// let p=poloto::Plotter::new(svg,"title","x","y");
+    /// let svg = poloto::default_svg();
+    /// let p = poloto::Plotter::new(svg, "title", "x", "y");
     /// ```
     pub fn new(
         element: tagger::Element<'a>,
